@@ -1,5 +1,8 @@
 import unittest
 import os.path
+import datetime
+
+from pyasn1.type import univ
 
 import rfc3161
 
@@ -9,11 +12,9 @@ class Rfc3161(unittest.TestCase):
             '../data/certum_certificate.crt')
 
     def test_timestamp(self):
-        try:
-            certificate = file(self.CERTIFICATE).read()
-            value, substrate = rfc3161.RemoteTimestamper(
-                    self.PUBLIC_TSA_SERVER, certificate=certificate)(data='xx')
-        except rfc3161.TimestampingError:
-            return
+        certificate = file(self.CERTIFICATE).read()
+        value, substrate = rfc3161.RemoteTimestamper(
+                self.PUBLIC_TSA_SERVER, certificate=certificate)(data='xx')
+        self.assertIsInstance(rfc3161.get_timestamp(value), datetime.datetime)
         self.assertNotEqual(value, None)
         self.assertEqual(substrate, '')
